
/* dynamic_load - ͭ饤֥Υɤȼ¹ */

/* $Id: dynamic_load.c,v 1.2 2003/05/19 05:36:37 tosihisa Exp $ */

#include <stdio.h>
#ifdef HAVE_DL
#include <dlfcn.h>
#endif

#include "tnetio.h"

int tnetio_dluse(void)
{
#ifdef HAVE_DL
	return 1;	/* ͭ饤֥굡ǽϻѲǽ */
#else
	tnetio_log_write(" ABORT : Not supported : Dynamic-link library function.\n");
	return 0;	/* ͭ饤֥굡ǽϻѤǤʤ */
#endif
}

void *tnetio_dlopen(char *libname)
{
#ifdef HAVE_DL
	return dlopen(libname,RTLD_NOW /* RTLD_LAZY */);
#else
	return NULL;
#endif
}

void *tnetio_dlsym(void *handler,char *funcname)
{
#ifdef HAVE_DL
	if(handler == NULL)
		return NULL;

	return dlsym(handler,funcname);
#else
	return NULL;
#endif
}

int tnetio_dlclose(void *handler)
{
#ifdef HAVE_DL
	return dlclose(handler);
#else
	return -1;
#endif
}

const char *tnetio_dlerror(void)
{
#ifdef HAVE_DL
	return dlerror();
#else
	return "";
#endif
}

